@@ -33,7 +33,7 @@ import ujson
 from .clans import Clan, RankedClan
 from .errors import Forbidden, GatewayError, NotFound, PrivateWarLog
 from .enums import WarRound
-from .miscmodels import Label, League, Location, LoadGameData
+from .miscmodels import GoldPassSeason, Label, League, Location, LoadGameData
 from .hero import HeroHolder, PetHolder
 from .http import HTTPClient, BasicThrottler, BatchThrottler
 from .iterators import (
@@ -44,10 +44,12 @@ from .iterators import (
     CurrentWarIterator,
 )
 from .players import Player, ClanMember, RankedPlayer
+from .raid import RaidLogEntry
 from .spell import SpellHolder
 from .troop import TroopHolder
 from .utils import correct_tag, get, parse_army_link
 from .wars import ClanWar, ClanWarLogEntry, ClanWarLeagueGroup
+from.entry_logs import ClanWarLog, RaidLog
 
 if TYPE_CHECKING:
     from .hero import Hero, Pet
@@ -196,6 +198,13 @@ class Client:
         self._clans = {}
         self._wars = {}
 
+    async def __aenter__(self):
+        self.__init__()
+        return self
+
+    async def __aexit__(self, *args):
+        await self.close()
+
     def _create_client(self, email, password):
         return HTTPClient(
             client=self,
@@ -493,9 +502,18 @@ class Client:
         self,
         clan_tag: str,
         cls: Type[ClanWarLogEntry] = ClanWarLogEntry,
-        **kwargs
-    ) -> List[ClanWarLogEntry]:
-        """Retrieve a clan's clan war log.
+        page: bool = False,
+        limit: int = 0
+    ) -> ClanWarLog:
+        """
+        Retrieve a clan's clan war log. By default, this will return
+        all the clan's log available in the API. This will of course consume
+        memory. The option of limiting the amount of log items fetched
+        can be controlled with the `limit` parameter. Additionally, if
+        `paginate` is set to True, and an async for loop is performed
+        on this object, then additional log items will be fetched but only
+        consume the same amount of memory space at all time.
+
 
         .. note::
 
@@ -506,8 +524,20 @@ class Client:
 
         Parameters
         -----------
-        clan_tag : str
-            The clan tag to search for.
+        cls:
+            Target class to use to model that data returned
+
+        clan_tag:
+            class:`str`: The clan tag to search for.
+
+        page:
+            class:`bool`: Enable fetching logs while only holding the
+            same amount of logs as `limit`. If `paginate` is set to True,
+            and `limit` is set to default of 0, then `limit` will be set to
+            10 automatically.
+
+        limit:
+            class:`int`: Number of logs to retrieve
 
         Raises
         ------
@@ -529,21 +559,114 @@ class Client:
 
         Returns
         --------
-        List[:class:`ClanWarLogEntry`]
+        :class:`ClanWarLog`:
             Entries in the warlog of the requested clan.
         """
+        if limit < 0:
+            raise ValueError("Limit cannot be negative")
+
         if not issubclass(cls, ClanWarLogEntry):
             raise TypeError("cls must be a subclass of ClanWarLogEntry.")
 
         if self.correct_tags:
             clan_tag = correct_tag(clan_tag)
 
-        try:
-            data = await self.http.get_clan_warlog(clan_tag)
-        except Forbidden as exception:
-            raise PrivateWarLog(exception.response, exception.reason) from exception
+        # If paginate is enabled and limit is set to default of 0, then
+        # set limit to a new default of 10
+        if page:
+            limit = limit if limit else 10
 
-        return [cls(data=wdata, client=self, **kwargs) for wdata in data.get("items", [])]
+        try:
+            return await ClanWarLog.init_cls(client=self,
+                                             clan_tag=clan_tag,
+                                             page=page,
+                                             limit=limit,
+                                             model=cls)
+        except Forbidden as exception:
+            raise PrivateWarLog(exception.response,
+                                exception.reason) from exception
+
+    async def get_raidlog(
+            self,
+            clan_tag: str,
+            cls: Type[RaidLogEntry] = RaidLogEntry,
+            page: bool = False,
+            limit: int = 0
+    ) -> RaidLog:
+        """
+        Retrieve a clan's Capital Raid Log. By default, this will return
+        all the clan's log available in the API. This will of course consume
+        memory. The option of limiting the amount of log items fetched
+        can be controlled with the `limit` parameter. Additionally, if
+        `paginate` is set to True, and an async for loop is performed
+        on this object, then additional log items will be fetched but only
+        consume the same amount of memory space at all time.
+
+
+        Parameters
+        -----------
+        cls:
+            Target class to use to model that data returned
+
+        clan_tag:
+            class:`str`: The clan tag to search for.
+
+        page:
+            class:`bool`: Enable fetching logs while only holding the
+            same amount of logs as `limit`. If `paginate` is set to True,
+            and `limit` is set to default of 0, then `limit` will be set to
+            10 automatically.
+
+        limit:
+            class:`int`: Number of logs to retrieve
+
+        Raises
+        ------
+        TypeError
+            The ``cls`` parameter must be a subclass of :class:`RaidLogEntry`.
+
+        NotFound
+            No clan was found with the supplied tag.
+
+        PrivateWarLog
+            The clan's warlog is private.
+
+        Maintenance
+            The API is currently in maintenance.
+
+        GatewayError
+            The API hit an unexpected gateway exception.
+
+
+        Returns
+        --------
+        :class:`RaidLog`:
+            Entries in the capital raid seasons of the requested clan.
+        """
+
+        if limit < 0:
+            raise ValueError("Limit cannot be negative")
+
+        if not issubclass(cls, RaidLogEntry):
+            raise TypeError("cls must be a subclass of ClanWarLogEntry.")
+
+        if self.correct_tags:
+            clan_tag = correct_tag(clan_tag)
+
+        # If paginate is enabled and limit is set to default of 0, then
+        # set limit to a new default of 10
+        if page:
+            limit = limit if limit else 10
+
+        try:
+            return await RaidLog.init_cls(client=self,
+                                          clan_tag=clan_tag,
+                                          page=page,
+                                          limit=limit,
+                                          model=cls)
+        except Forbidden as exception:
+            raise PrivateWarLog(exception.response,
+                                exception.reason) from exception
 
     async def get_clan_war(self, clan_tag: str, cls: Type[ClanWar] = ClanWar, **kwargs) -> ClanWar:
         """
@@ -1520,6 +1643,24 @@ class Client:
         data = await self.http.verify_player_token(player_tag, token)
         return data and data["status"] == "ok" or False
 
+    async def get_current_goldpass_season(self) -> GoldPassSeason:
+        """Get the current gold pass season
+
+        Raises
+        ------
+        Maintenance
+            The API is currently in maintenance.
+
+        GatewayError
+            The API hit an unexpected gateway exception.
+
+        Returns
+        --------
+        :class:`GoldPassSeason`
+            The gold pass season object of the current season"""
+        data = await self.http.get_current_goldpass_season()
+        return GoldPassSeason(data=data)
+
     def parse_army_link(self, link: str):
         """Transform an army link from in-game into a list of troops and spells.
 
