@@ -41,7 +41,10 @@ DEFAULT_SLEEP = 10
 
 
 class Event:
-    """Object that is created for an event. This contains runner functions, tags and type."""
+    """
+    Object that is created for an event. This contains runner functions,
+    tags and type.
+    """
 
     __slots__ = ("runner", "callback", "tags", "type")
 
@@ -719,13 +722,6 @@ class EventsClient(Client):
         except KeyboardInterrupt:
             self.close()
 
-    def close(self):
-        """Closes the client and all running tasks."""
-        tasks = {t for t in asyncio.Task.all_tasks(loop=self.loop) if not t.done()}
-        for task in tasks:
-            task.cancel()
-        super().close()
-
     def dispatch(self, event_name: str, *args, **kwargs):
         # pylint: disable=broad-except
         registered = self._listeners["client"].get(event_name)
