@@ -143,7 +143,23 @@ class Route:
 
     BASE = "https://api.clashofclans.com/v1"
 
-    def __init__(self, method, path: str, **kwargs):
+    def __init__(self, method: str, path: str, **kwargs: dict):
+        """
+        The class is used to create the final URL used to fetch the data
+        from the API. The parameters that are passed to the API are all in
+        the GET request packet. This class will parse the `kwargs` dictionary
+        and concatenate any parameters passed in.
+
+        Parameters
+        ----------
+        method:
+            :class:`str`: HTTP method used for the HTTP request
+        path:
+            :class:`str`: URL path used for the HTTP request
+        kwargs:
+            :class:`dict`: Optional options used to concatenate into the final
+            URL
+        """
         if "#" in path:
             path = path.replace("#", "%23")
 
@@ -339,18 +355,18 @@ class HTTPClient:
     def get_clan(self, tag):
         return self.request(Route("GET", "/clans/{}".format(tag)))
 
-    def get_clan_members(self, tag):
-        return self.request(Route("GET", "/clans/{}/members".format(tag)))
+    def get_clan_members(self, tag, **kwargs):
+        return self.request(Route("GET", "/clans/{}/members".format(tag), **kwargs))
 
-    def get_clan_warlog(self, tag):
-        return self.request(Route("GET", "/clans/{}/warlog".format(tag)))
+    def get_clan_warlog(self, tag, **kwargs):
+        return self.request(Route("GET", "/clans/{}/warlog".format(tag), **kwargs))
 
-    def get_clan_current_war(self, tag, realtime = None):
+    def get_clan_current_war(self, tag, realtime=None):
         return self.request(Route("GET", "/clans/{}/currentwar".format(tag) + (
                                          '?realtime=true' if realtime or (realtime is None and self.client.realtime)
                                          else '')))
 
-    def get_clan_war_league_group(self, tag, realtime = None):
+    def get_clan_war_league_group(self, tag, realtime=None):
         return self.request(Route("GET", "/clans/{}/currentwar/leaguegroup".format(tag) + (
                                          '?realtime=true' if realtime or (realtime is None and self.client.realtime)
                                          else '')))
@@ -360,6 +376,9 @@ class HTTPClient:
                                          '?realtime=true' if realtime or (realtime is None and self.client.realtime)
                                          else '')))
 
+    def get_clan_raidlog(self, tag, **kwargs):
+        return self.request(Route("GET", "/clans/{}/capitalraidseasons".format(tag), **kwargs))
+
     # locations
 
     def search_locations(self, **kwargs):
@@ -410,6 +429,9 @@ class HTTPClient:
     def get_player_labels(self, **kwargs):
         return self.request(Route("GET", "/labels/players", **kwargs))
 
+    def get_current_goldpass_season(self):
+        return self.request(Route("GET", "/goldpass/seasons/current"))
+
     # key updating management
 
     async def initialise_keys(self):
